@@ -1,7 +1,9 @@
 import datetime
+import json
 import pathlib
 import time
 import os
+import subprocess
 
 def logger(message, level="INFO"):
     print(f"[{level}] {message}")
@@ -18,22 +20,19 @@ def delete(filepath):
 def file_exists(filepath):
     return pathlib.Path(filepath).exists()
 
-def make_dir(filepath):
-    try:
-        os.makedirs(pathlib.Path(filepath).parent)
-    except FileExistsError:
-        pass
+def make_parent_directory(filepath):
+    return os.makedirs(pathlib.Path(filepath).parent, exist_ok=True)
 
 def write_config(filepath=None, parser=None):
     "Write Config Parameters to filepath"
-    make_dir(filepath)
+    make_parent_directory(filepath)
     with open(filepath, "w") as configfile:
         parser.write(configfile)
 
 def write_file(filepath=None, data=None):
     "Write Credentials to filepath"
     filepath = filepath.replace('\\', '/')
-    make_dir(filepath)
+    make_parent_directory(filepath)
     logger(f"Writing data to {filepath}")
     with open(filepath, "w") as writer:
         writer.write(str(data))
@@ -64,4 +63,37 @@ def to_camel_case(text):
     return ''.join(text.title().split('-'))
 
 def get_commit_message():
-    return input("Enter commit message: ")
\ No newline at end of file
+    return input("Enter commit message: ")
+
+def read_json(filepath):
+    '''Return a dictionary from a json file'''
+    with open(f'{filepath}.template.json') as template:
+        return json.load(template)
+
+def run_in_shell(command):
+    result = time_it(
+        command,
+        function=subprocess.run,
+        description=command,
+        shell=True,
+        capture_output=True,
+    )
+    print(result.stderr.decode())
+    print(result.stdout.decode())
+    return result
+
+def publish(distribute=False):
+    if run_in_shell('git diff').stdout.decode():
+        for command in (
+            f'commit -am "{get_commit_message()}"',
+            'pull',
+            'push',
+        ):
+            run_in_shell(f'git {command}')
+        if distribute:
+            for command in (
+                'build',
+                'twine upload dist/*',
+            ):
+                result = run_in_shell(f'python3 -m {command}')
+            return result.returncode
\ No newline at end of file
